==> aterm-2.3.1.tar.gz: aterm-2.3.1/test/terms.c <==
/*
 * Generated at Wed Dec  1 23:04:16 2004
 */

#include "terms.h"

AFun symbolA;
AFun symbolB;

ATerm patternA = NULL;
ATerm patternB = NULL;

/*
 * symbolA = "A very complex symbol"(1,2,3)
 * symbolB = "another \"complex\" symbol"
 *
 * patternA = patroon("a",<term>)
 * patternB = patroon("b")
 *
 */

static ATerm _terms_dict = NULL;

#define _terms_dict_LEN 174

static char _terms_dict_baf[_terms_dict_LEN] = {
0x00,0x8B,0xAF,0x83,0x00,0x0B,0x12,0x05,0x3C,0x69,0x6E,0x74,0x3E,0x00,0x00,0x03,
0x03,0x3C,0x5F,0x3E,0x01,0x00,0x01,0x01,0x04,0x05,0x5B,0x5F,0x2C,0x5F,0x5D,0x02,
0x00,0x06,0x05,0x02,0x08,0x0A,0x05,0x06,0x02,0x02,0x03,0x02,0x5B,0x5D,0x00,0x00,
0x01,0x04,0x74,0x65,0x72,0x6D,0x00,0x00,0x01,0x15,0x41,0x20,0x76,0x65,0x72,0x79,
0x20,0x63,0x6F,0x6D,0x70,0x6C,0x65,0x78,0x20,0x73,0x79,0x6D,0x62,0x6F,0x6C,0x03,
0x01,0x01,0x01,0x00,0x01,0x00,0x01,0x00,0x18,0x61,0x6E,0x6F,0x74,0x68,0x65,0x72,
0x20,0x22,0x63,0x6F,0x6D,0x70,0x6C,0x65,0x78,0x22,0x20,0x73,0x79,0x6D,0x62,0x6F,
0x6C,0x00,0x01,0x01,0x01,0x61,0x00,0x01,0x01,0x07,0x70,0x61,0x74,0x72,0x6F,0x6F,
0x6E,0x02,0x00,0x01,0x01,0x07,0x01,0x01,0x01,0x62,0x00,0x01,0x01,0x07,0x70,0x61,
0x74,0x72,0x6F,0x6F,0x6E,0x01,0x00,0x01,0x01,0x09,0x02,0x13,0x10,0x00,0x00,0x00,
0x12,0x00,0x00,0x00,0x03,0x80,0x00,0x00,0x00,0x03,0x04,0x68,0x25,0x40
};

void init_terms_dict()
{
  ATermList afuns, terms;

  _terms_dict = ATreadFromBinaryString(_terms_dict_baf, _terms_dict_LEN);

  ATprotect(&_terms_dict);

  afuns = (ATermList)ATelementAt((ATermList)_terms_dict, 0);

  symbolA = ATgetAFun((ATermAppl)ATgetFirst(afuns));
  afuns = ATgetNext(afuns);
  symbolB = ATgetAFun((ATermAppl)ATgetFirst(afuns));
  afuns = ATgetNext(afuns);

  terms = (ATermList)ATelementAt((ATermList)_terms_dict, 1);

  patternA = ATgetFirst(terms);
  terms = ATgetNext(terms);
  patternB = ATgetFirst(terms);
  terms = ATgetNext(terms);
}

==> aterm-2.8.tar.gz: aterm-2.8/test/terms.c <==
/*
 * Generated at Wed Sep  3 16:32:04 2008
 */

#include "terms.h"

AFun symbolA;
AFun symbolB;

ATerm patternA = NULL;
ATerm patternB = NULL;

/*
 * symbolA = "A very complex symbol"(1,2,3)
 * symbolB = "another \"complex\" symbol"
 *
 * patternA = patroon("a",<term>)
 * patternB = patroon("b")
 *
 */

static ATerm _terms_dict = NULL;

#define _terms_dict_LEN 174

static unsigned char _terms_dict_baf[_terms_dict_LEN] = {
0x00,0x8B,0xAF,0x83,0x00,0x0B,0x12,0x05,0x3C,0x69,0x6E,0x74,0x3E,0x00,0x00,0x03,
0x03,0x3C,0x5F,0x3E,0x01,0x00,0x01,0x01,0x04,0x05,0x5B,0x5F,0x2C,0x5F,0x5D,0x02,
0x00,0x06,0x05,0x02,0x08,0x0A,0x05,0x06,0x02,0x02,0x03,0x02,0x5B,0x5D,0x00,0x00,
0x01,0x04,0x74,0x65,0x72,0x6D,0x00,0x00,0x01,0x15,0x41,0x20,0x76,0x65,0x72,0x79,
0x20,0x63,0x6F,0x6D,0x70,0x6C,0x65,0x78,0x20,0x73,0x79,0x6D,0x62,0x6F,0x6C,0x03,
0x01,0x01,0x01,0x00,0x01,0x00,0x01,0x00,0x18,0x61,0x6E,0x6F,0x74,0x68,0x65,0x72,
0x20,0x22,0x63,0x6F,0x6D,0x70,0x6C,0x65,0x78,0x22,0x20,0x73,0x79,0x6D,0x62,0x6F,
0x6C,0x00,0x01,0x01,0x01,0x61,0x00,0x01,0x01,0x07,0x70,0x61,0x74,0x72,0x6F,0x6F,
0x6E,0x02,0x00,0x01,0x01,0x07,0x01,0x01,0x01,0x62,0x00,0x01,0x01,0x07,0x70,0x61,
0x74,0x72,0x6F,0x6F,0x6E,0x01,0x00,0x01,0x01,0x09,0x02,0x13,0x10,0x00,0x00,0x00,
0x12,0x00,0x00,0x00,0x03,0x80,0x00,0x00,0x00,0x03,0x04,0x68,0x25,0x40
};

void init_terms_dict()
{
  ATermList afuns, terms;

  _terms_dict = ATreadFromBinaryString(_terms_dict_baf, _terms_dict_LEN);

  ATprotect(&_terms_dict);

  afuns = (ATermList)ATelementAt((ATermList)_terms_dict, 0);

  symbolA = ATgetAFun((ATermAppl)ATgetFirst(afuns));
  ATprotectAFun(symbolA);
  afuns = ATgetNext(afuns);
  symbolB = ATgetAFun((ATermAppl)ATgetFirst(afuns));
  ATprotectAFun(symbolB);
  afuns = ATgetNext(afuns);

  terms = (ATermList)ATelementAt((ATermList)_terms_dict, 1);

  patternA = ATgetFirst(terms);
  terms = ATgetNext(terms);
  patternB = ATgetFirst(terms);
  terms = ATgetNext(terms);
}
